@@ -33,8 +33,7 @@ def test_extract_html():
         'simple.docx',
     )
     actual_html = convert(file_path)
-    assert_html_equal(actual_html,
-    '''
+    assert_html_equal(actual_html, '''
     <html>
         <p>
           Simple text
@@ -66,8 +65,7 @@ def test_nested_list():
         'nested_lists.docx',
     )
     actual_html = convert(file_path)
-    assert_html_equal(actual_html,
-    '''
+    assert_html_equal(actual_html, '''
     <html>
         <ol data-list-type="decimal">
             <li>one</li>
@@ -111,8 +109,7 @@ def test_simple_list():
         'simple_lists.docx',
     )
     actual_html = convert(file_path)
-    assert_html_equal(actual_html,
-    '''
+    assert_html_equal(actual_html, '''
     <html>
         <ol data-list-type="decimal">
             <li>One</li>
@@ -132,8 +129,7 @@ def test_inline_tags():
         'inline_tags.docx',
     )
     actual_html = convert(file_path)
-    assert_html_equal(actual_html,
-    '''
+    assert_html_equal(actual_html, '''
     <html><p>This sentence has some <strong>bold</strong>, some <em>italics</em> and some <strong>underline</strong>, as well as a <a href="http://www.google.com/">hyperlink</a>.</p></html>''')  # noqa
 
 
@@ -716,18 +712,6 @@ def test_upper_alpha_all_bold():
     ''')
 
 
-def test():
-    file_path = path.join('/home/jason/Downloads/Discharge Planning referral.docx')
-    actual_html = convert(file_path)
-    assert_html_equal(actual_html, '''
-    <html>
-        <h2>AAA</h2>
-        <h2>BBB</h2>
-        <h2>CCC</h2>
-    </html>
-    ''')
-
-
 def _converter(*args, **kwargs):
     # Having a converter that does nothing is the same as if abiword fails to
     # convert.
